Recording WAV files

Dependencies:   mbed SDFileSystem

Revision:
7:4467fbfa888b
Parent:
4:fc36c8ec2966
--- a/check_revision.cpp	Fri Dec 27 03:01:20 2019 +0000
+++ b/check_revision.cpp	Sat May 02 03:45:17 2020 +0000
@@ -1,20 +1,31 @@
 /*
  * Check Mbed revision
  *
- * Copyright (c) 2019 Kenji Arai / JH1PJL
- *  http://www.page.sannet.ne.jp/kenjia/index.html
+ * Copyright (c) 2019,'20 Kenji Arai / JH1PJL
+ *  http://www7b.biglobe.ne.jp/~kenjia/
  *  https://os.mbed.com/users/kenjiArai/
  *      Created:    July      17th, 2019
- *      Revised:    August    17th, 2019
+ *      Revised:    May        2nd, 2020
  */
 
 #include "mbed.h"
-
-//    RUN ONLY ON mbed 2.0.165
-#if (MBED_MAJOR_VERSION == 2) &&\
+ 
+//    RUN ONLY ON mbed-os-5.15.3
+//      https://github.com/ARMmbed/mbed-os/releases/tag/mbed-os-5.15.3
+#if (MBED_MAJOR_VERSION == 5) &&\
+    (MBED_MINOR_VERSION == 15) &&\
+    (MBED_PATCH_VERSION == 3)
+#elif (MBED_MAJOR_VERSION == 2) &&\
     (MBED_MINOR_VERSION == 0) &&\
     (MBED_PATCH_VERSION == 165)
 #else
-    //#warning "Please use mbed 2.0.165"
-    #error "Please use mbed 2.0.165"
-#endif
\ No newline at end of file
+    //#warning "Please use mbed-os-5.15.3 or mbed 2.0.165"
+    #error "Please use mbed-os-5.15.3 or mbed 2.0.165"
+#endif
+
+void print_revision(void)
+{
+    printf("MBED_MAJOR_VERSION = %d, ", MBED_MAJOR_VERSION);
+    printf("MINOR = %d, ", MBED_MINOR_VERSION);
+    printf("PATCH = %d\r\n", MBED_PATCH_VERSION);
+}